Exception: Parse::AtlasSearch::ACLRequired

Inherits:
StandardError
  • Object
show all
Defined in:
lib/parse/atlas_search.rb

Overview

Error raised when the caller did not supply +session_token:+ or +master: true+ and require_session_token is +true+. Atlas Search bypasses Parse Server's ACL evaluation, so the caller must either pass a session token (so the SDK can inject a +_rperm+ +$match+) or explicitly opt into master-key semantics.