Exception: Parse::Cache::UnscopedClearRefused

Inherits:
StandardError
  • Object
show all
Defined in:
lib/parse/cache/scoped_view.rb

Overview

Raised when a keyspaced client is asked to clear a cache store that cannot restrict the clear to its own keyspace.