Class: Parse::Constraint::ContainsConstraint
- Inherits:
-
Parse::Constraint
- Object
- Parse::Constraint
- Parse::Constraint::ContainsConstraint
- Defined in:
- lib/parse/query/constraints.rb
Overview
Equivalent to using the $regex Parse query operation with a contains pattern.
This is useful for case-insensitive text search within fields.
# Find posts whose title contains "parse" Post.where(:title.contains => "parse") # Generates: "title": { "$regex": ".parse.", "$options": "i" }
# Opt into Unicode-aware case-insensitive matching (Parse Server 8.3.0+ # over REST, MongoDB 6.1+ mongo-direct): Post.where(:title.contains => { value: "café", unicode: true }) # Generates: "title": { "$regex": ".café.", "$options": "iu" }
Instance Attribute Summary
Attributes inherited from Parse::Constraint
#operand, #operation, #operator, #value
Instance Method Summary collapse
-
#build ⇒ Hash
The compiled constraint.
-
#contains ⇒ ContainsConstraint
A registered method on a symbol to create the constraint.
Methods inherited from Parse::Constraint
#as_json, constraint_keyword, create, formatted_value, #formatted_value, #initialize, #key, #precedence, #regex_unicode_option, register, #to_s
Constructor Details
This class inherits a constructor from Parse::Constraint
Instance Method Details
#build ⇒ Hash
Returns the compiled constraint.
2406 2407 2408 2409 2410 2411 2412 2413 2414 2415 2416 2417 2418 2419 2420 2421 2422 2423 |
# File 'lib/parse/query/constraints.rb', line 2406 def build raw, unicode = regex_unicode_option(@value) value = self.class.formatted_value(raw) unless value.is_a?(String) raise ArgumentError, "#{self.class}: Value must be a string for contains constraint" end # Validate length to prevent performance issues if value.length > Parse::RegexSecurity::MAX_PATTERN_LENGTH raise ArgumentError, "#{self.class}: Value too long (#{value.length} chars, max #{Parse::RegexSecurity::MAX_PATTERN_LENGTH})" end # Escape special regex characters in the search text escaped_value = Regexp.escape(value) regex_pattern = ".*#{escaped_value}.*" { @operation.operand => { :$regex => regex_pattern, :$options => (unicode ? "iu" : "i") } } end |
#contains ⇒ ContainsConstraint
A registered method on a symbol to create the constraint. Maps to Parse operator "$regex".
2402 |
# File 'lib/parse/query/constraints.rb', line 2402 constraint_keyword :$regex |