Module: Parse::Core::EnhancedChangeTracking::ClassMethods
- Defined in:
- lib/parse/model/core/enhanced_change_tracking.rb
Instance Method Summary collapse
-
#property(key, data_type = :string, **opts) ⇒ Object
Override the property method to add enhanced change tracking after the ActiveModel methods are defined.
Instance Method Details
#property(key, data_type = :string, **opts) ⇒ Object
Override the property method to add enhanced change tracking after the ActiveModel methods are defined
39 40 41 42 43 44 45 46 |
# File 'lib/parse/model/core/enhanced_change_tracking.rb', line 39 def property(key, data_type = :string, **opts) result = super # Call the original property method # After property is defined, override the _changed? and _was methods enhance_change_tracking_for_field(key) result end |