Module: Parse::Protocol

Included in:
Middleware::Authentication, Middleware::BodyBuilder, Middleware::Caching
Defined in:
lib/parse/client/protocol.rb

Overview

Set of Parse protocol constants.

Constant Summary collapse

SERVER_URL =

The default server url, based on the hosted Parse platform. Uses HTTPS by default for security. Override with ENV or pass server_url: to Parse.setup for custom configurations.

"https://localhost:1337/parse".freeze
APP_ID =

The request header field to send the application Id.

"X-Parse-Application-Id"
API_KEY =

The request header field to send the REST API key.

"X-Parse-REST-API-Key"
MASTER_KEY =

The request header field to send the Master key.

"X-Parse-Master-Key"
SESSION_TOKEN =

The request header field to send the revocable Session key.

"X-Parse-Session-Token"
REVOCABLE_SESSION =

The request header field to request a revocable session token.

"X-Parse-Revocable-Session"
INSTALLATION_ID =

The request header field to send the installation id.

"Parse-Installation-Id"
EMAIL =

The request header field to send an email when authenticating with Parse hosted platform.

"X-Parse-Email"
PASSWORD =

The request header field to send the password when authenticating with the Parse hosted platform.

"X-Parse-Password"
CONTENT_TYPE =

The request header field for the Content type.

"Content-Type"
CONTENT_TYPE_FORMAT =

The default content type format for sending API requests.

"application/json; charset=utf-8"
READ_PREFERENCE =

The request header field for MongoDB read preference. Supported values: PRIMARY, PRIMARY_PREFERRED, SECONDARY, SECONDARY_PREFERRED, NEAREST

"X-Parse-Read-Preference"
READ_PREFERENCES =

Valid read preference values for MongoDB

%w[PRIMARY PRIMARY_PREFERRED SECONDARY SECONDARY_PREFERRED NEAREST].freeze