Module: Parse::API::Aggregate
- Included in:
- Client
- Defined in:
- lib/parse/api/aggregate.rb
Overview
REST API methods for fetching CRUD operations on Parse objects.
Defined Under Namespace
Modules: ClassMethods
Instance Method Summary collapse
-
#aggregate_objects(className, query = {}, headers: {}, **opts) ⇒ Parse::Response
Aggregate a set of matching objects for a query.
-
#aggregate_pipeline(className, pipeline = [], headers: {}, **opts) ⇒ Parse::Response
Execute a MongoDB-style aggregation pipeline on a Parse collection.
-
#aggregate_uri_path(className) ⇒ String
Get the API path for this class.
Instance Method Details
#aggregate_objects(className, query = {}, headers: {}, **opts) ⇒ Parse::Response
Aggregate a set of matching objects for a query.
58 59 60 61 62 |
# File 'lib/parse/api/aggregate.rb', line 58 def aggregate_objects(className, query = {}, headers: {}, **opts) response = request :get, aggregate_uri_path(className), query: query, headers: headers, opts: opts response.parse_class = className if response.present? response end |
#aggregate_pipeline(className, pipeline = [], headers: {}, **opts) ⇒ Parse::Response
Execute a MongoDB-style aggregation pipeline on a Parse collection.
71 72 73 74 75 76 |
# File 'lib/parse/api/aggregate.rb', line 71 def aggregate_pipeline(className, pipeline = [], headers: {}, **opts) query = { pipeline: pipeline.to_json } response = request :get, aggregate_uri_path(className), query: query, headers: headers, opts: opts response.parse_class = className if response.present? response end |
#aggregate_uri_path(className) ⇒ String
Get the API path for this class.
47 48 49 |
# File 'lib/parse/api/aggregate.rb', line 47 def aggregate_uri_path(className) self.class.aggregate_uri_path(className) end |