Module: Parse::Agent::MetadataDSL
- Included in:
- Object
- Defined in:
- lib/parse/agent/metadata_dsl.rb
Overview
DSL module that adds agent metadata capabilities to Parse::Object models. Allows models to self-document with descriptions and expose safe methods to the Parse Agent for LLM interaction.
Defined Under Namespace
Modules: ClassMethods
Class Method Summary collapse
Instance Method Summary collapse
-
#agent_description ⇒ String?
Instance method to access class-level agent description.
-
#agent_methods ⇒ Hash<Symbol, Hash>
Instance method to access class-level agent methods.
-
#property_descriptions ⇒ Hash<Symbol, String>
Instance method to access class-level property descriptions.
-
#property_enum_descriptions ⇒ Hash<Symbol, Hash{String => String}>
Instance method to access class-level per-value enum descriptions.
Class Method Details
.included(base) ⇒ Object
30 31 32 |
# File 'lib/parse/agent/metadata_dsl.rb', line 30 def self.included(base) base.extend(ClassMethods) end |
Instance Method Details
#agent_description ⇒ String?
Instance method to access class-level agent description
707 708 709 |
# File 'lib/parse/agent/metadata_dsl.rb', line 707 def agent_description self.class.agent_description end |
#agent_methods ⇒ Hash<Symbol, Hash>
Instance method to access class-level agent methods
728 729 730 |
# File 'lib/parse/agent/metadata_dsl.rb', line 728 def agent_methods self.class.agent_methods end |