Module: Parse::Client::Connectable::ClassMethods

Defined in:
lib/parse/client.rb

Overview

Class methods to be added to any object that wants to have standard access to a the default Parse::Client instance.

Instance Attribute Summary collapse

Instance Attribute Details

#clientObject



933
934
935
# File 'lib/parse/client.rb', line 933

def client
  @client ||= Parse::Client.client #defaults to :default tag
end