Module: Parse::Client::Connectable::ClassMethods
- Defined in:
- lib/parse/client.rb
Overview
Class methods to be added to any object that wants to have standard access to a the default Parse::Client instance.
Class methods to be added to any object that wants to have standard access to a the default Parse::Client instance.