Class: Parse::Constraint::EndsWithConstraint
- Inherits:
-
Parse::Constraint
- Object
- Parse::Constraint
- Parse::Constraint::EndsWithConstraint
- Defined in:
- lib/parse/query/constraints.rb
Overview
Equivalent to using the ‘$regex` Parse query operation with a suffix pattern. This is useful for matching fields that end with a specific string.
# Find files whose name ends with ".pdf"
File.where(:name.ends_with => ".pdf")
# Generates: "name": { "$regex": "\\.pdf$", "$options": "i" }
Instance Attribute Summary
Attributes inherited from Parse::Constraint
#operand, #operation, #operator, #value
Instance Method Summary collapse
-
#build ⇒ Hash
The compiled constraint.
-
#ends_with ⇒ EndsWithConstraint
A registered method on a symbol to create the constraint.
Methods inherited from Parse::Constraint
#as_json, constraint_keyword, create, formatted_value, #formatted_value, #initialize, #key, #precedence, register, #to_s
Constructor Details
This class inherits a constructor from Parse::Constraint
Instance Method Details
#build ⇒ Hash
Returns the compiled constraint.
2376 2377 2378 2379 2380 2381 2382 2383 2384 2385 2386 2387 2388 2389 2390 2391 2392 |
# File 'lib/parse/query/constraints.rb', line 2376 def build value = formatted_value unless value.is_a?(String) raise ArgumentError, "#{self.class}: Value must be a string for ends_with constraint" end # Validate length to prevent performance issues if value.length > Parse::RegexSecurity::MAX_PATTERN_LENGTH raise ArgumentError, "#{self.class}: Value too long (#{value.length} chars, max #{Parse::RegexSecurity::MAX_PATTERN_LENGTH})" end # Escape special regex characters in the suffix escaped_value = Regexp.escape(value) regex_pattern = "#{escaped_value}$" { @operation.operand => { :$regex => regex_pattern, :$options => "i" } } end |
#ends_with ⇒ EndsWithConstraint
A registered method on a symbol to create the constraint. Maps to Parse operator “$regex”.
2372 |
# File 'lib/parse/query/constraints.rb', line 2372 constraint_keyword :$regex |