Exception: Parse::CreateLockInvalidKey
- Defined in:
- lib/parse/stack.rb
Overview
Error raised when query_attrs passed to a synchronized ‘first_or_create!` contain values that cannot be canonicalized into a stable lock key (Procs, Regexps, query operators, unsaved pointers, nested Hashes, oversized payloads).
Instance Attribute Summary
Attributes inherited from Error
Method Summary
Methods inherited from Error
Constructor Details
This class inherits a constructor from Parse::Error