Exception: Parse::MongoDB::WriterNotConfigured
- Inherits:
-
StandardError
- Object
- StandardError
- Parse::MongoDB::WriterNotConfigured
- Defined in:
- lib/parse/mongodb.rb
Overview
Error raised when an index mutation primitive is invoked but the writer connection has not been configured via configure_writer.