Exception: Parse::PipelineSecurity::Error
- Defined in:
- lib/parse/pipeline_security.rb
Overview
Raised when a pipeline or filter contains a forbidden stage or operator. Inherits from ‘Parse::Error` so callers can rescue both this and other Parse SDK errors with one rescue clause.
Instance Attribute Summary collapse
-
#operator ⇒ Object
readonly
Returns the value of attribute operator.
-
#reason ⇒ Object
readonly
Returns the value of attribute reason.
-
#stage ⇒ Object
readonly
Returns the value of attribute stage.
Attributes inherited from Error
Instance Method Summary collapse
-
#initialize(message, stage: nil, operator: nil, reason: nil) ⇒ Error
constructor
A new instance of Error.
Constructor Details
#initialize(message, stage: nil, operator: nil, reason: nil) ⇒ Error
Returns a new instance of Error.
77 78 79 80 81 82 |
# File 'lib/parse/pipeline_security.rb', line 77 def initialize(, stage: nil, operator: nil, reason: nil) @stage = stage @operator = operator @reason = reason super() end |
Instance Attribute Details
#operator ⇒ Object (readonly)
Returns the value of attribute operator.
75 76 77 |
# File 'lib/parse/pipeline_security.rb', line 75 def operator @operator end |
#reason ⇒ Object (readonly)
Returns the value of attribute reason.
75 76 77 |
# File 'lib/parse/pipeline_security.rb', line 75 def reason @reason end |
#stage ⇒ Object (readonly)
Returns the value of attribute stage.
75 76 77 |
# File 'lib/parse/pipeline_security.rb', line 75 def stage @stage end |