Class: Parse::Product
- Defined in:
- lib/parse/model/classes/product.rb
Overview
This Parse feature is effectively deprecated. The ‘PFProduct` IAP integration was tied to hosted Parse and is not actively used by modern Parse Server deployments. Most apps now verify in-app purchase receipts directly against the Apple App Store or Google Play. The `_Product` collection and this class are retained for backwards compatibility with legacy applications that still read or write product metadata in this table.
This class represents the data and columns contained in the standard Parse ‘_Product` collection. These records were used when implementing in-app purchases in mobile applications via the original Parse iOS SDK’s ‘PFProduct` downloadable-content flow.
The default schema for Product is as follows:
class Parse::Product < Parse::Object
# See Parse::Object for inherited properties...
property :download, :file
property :icon, :file, required: true
property :order, :integer, required: true
property :subtitle, required: true
property :title, required: true
property :product_identifier, required: true
end
Constant Summary
Constants inherited from Object
Object::BUILTIN_PARSE_CLASS_NAMES, Object::IDENTIFICATION_FIELDS, Object::VALID_ACL_POLICIES
Constants included from Core::Schema
Core::Schema::DEFAULT_PUBLIC_CLP, Core::Schema::SCHEMA_READONLY_CLASSES
Constants included from Core::Describe
Core::Describe::ALL_SECTIONS, Core::Describe::CORE_FIELD_KEYS, Core::Describe::LOCAL_SECTIONS, Core::Describe::NETWORK_SECTIONS
Constants included from Core::Indexing
Core::Indexing::MAX_INDEXES_PER_COLLECTION, Core::Indexing::PARSE_MANAGED_ARRAY_FIELDS, Core::Indexing::SENSITIVE_FIELDS
Constants included from Core::SearchIndexing
Core::SearchIndexing::ALLOWED_INDEX_TYPES, Core::SearchIndexing::INDEX_NAME_PATTERN
Constants included from Core::Fetching
Core::Fetching::NON_SERIALIZABLE_IVARS
Constants included from Core::ParseReference
Core::ParseReference::OBJECT_ID_LENGTH, Core::ParseReference::SEPARATOR
Constants included from Core::FieldGuards
Core::FieldGuards::GUARD_MODES
Constants included from Properties
Parse::Properties::BASE, Parse::Properties::BASE_FIELD_MAP, Parse::Properties::BASE_KEYS, Parse::Properties::CORE_FIELDS, Parse::Properties::DELETE_OP, Parse::Properties::PROTECTED_INITIALIZE_KEYS, Parse::Properties::PROTECTED_MASS_ASSIGNMENT_KEYS, Parse::Properties::TYPES
Constants inherited from Pointer
Parse::Pointer::ATTRIBUTES, Parse::Pointer::OBJECT_ID_FORMAT
Constants inherited from Model
Model::CLASS_AUDIENCE, Model::CLASS_INSTALLATION, Model::CLASS_JOB_SCHEDULE, Model::CLASS_JOB_STATUS, Model::CLASS_PRODUCT, Model::CLASS_PUSH_STATUS, Model::CLASS_ROLE, Model::CLASS_SCHEMA, Model::CLASS_SESSION, Model::CLASS_USER, Model::ID, Model::KEY_CLASS_NAME, Model::KEY_CREATED_AT, Model::KEY_OBJECT_ID, Model::KEY_UPDATED_AT, Model::OBJECT_ID, Model::TYPE_ACL, Model::TYPE_BYTES, Model::TYPE_DATE, Model::TYPE_FIELD, Model::TYPE_FILE, Model::TYPE_GEOPOINT, Model::TYPE_NUMBER, Model::TYPE_OBJECT, Model::TYPE_POINTER, Model::TYPE_POLYGON, Model::TYPE_RELATION
Instance Attribute Summary collapse
-
#download ⇒ String
The file payload for this product download.
-
#download_name ⇒ String
The name of this download.
-
#icon ⇒ String
An icon file representing this download.
-
#order ⇒ String
The product order number.
-
#product_identifier ⇒ String
The product identifier.
-
#subtitle ⇒ String
The subtitle description for this product.
-
#title ⇒ String
The title for this product.
Attributes inherited from Object
#acl, #created_at, #id, #updated_at
Attributes inherited from Pointer
Method Summary
Methods inherited from Object
#[], #[]=, #__type, #_resolve_acl_owner_id, #_resolve_default_acl, #acl_changed?, acl_owner_field, acl_policy, acl_policy_setting, #acl_was, #acl_will_change!, #after_create, #after_destroy, #after_save, #after_update, #after_validation, #apply_defaults!, #around_create, #around_destroy, #around_save, #around_update, #around_validation, #as_json, #autofetch_disabled?, #before_create, #before_destroy, #before_save, #before_update, #before_validation, build, #changed, #changed?, class_permissions, #clear_attribute_change!, #clear_changes!, #clear_partial_fetch_state!, default_acls, describe_access, #disable_autofetch!, #enable_autofetch!, #existed?, fetch_clp, #fetched?, #fetched_keys, #fetched_keys=, #field_was_fetched?, #filter_for_user, filter_results_for_user, #fully_fetched?, #has?, #has_selective_keys?, #initialize, #keys, master_only_class!, #nested_fetched_keys, #nested_fetched_keys=, #nested_keys_for, #new?, #parse_class, #partially_fetched?, #persisted?, pointer, #pretty, private_acl!, protect_fields, #reload!, roles_for_user, #rollback!, #run_after_create_callbacks, #run_after_delete_callbacks, #run_after_save_callbacks, #schema, set_class_access, set_clp, set_default_acl, set_default_clp, set_read_user_fields, set_write_user_fields, #twin, unlistable_class!, update_clp!, #updates, #valid?, #validate!, webhook, webhook_function
Methods included from Core::Querying
#all, #count, #count_distinct, #cursor, #distinct, #each, #find, #find_cached, #first, #last_updated, #latest, #literal_where, #newest, #oldest, #query, #scope, #subscribe
Methods included from Core::Schema
#_default_class_level_permissions_for_upgrade, #auto_upgrade!, #create_schema, #fetch_schema, #reset_clp!, #schema, #update_schema
Methods included from Core::Describe
Methods included from Core::Indexing
#apply_indexes!, #indexes_plan, #mongo_geo_index, #mongo_index, #mongo_index_declarations, #mongo_relation_index
Methods included from Core::SearchIndexing
#apply_search_indexes!, #mongo_search_index, #mongo_search_index_declarations, #search_indexes_plan
Methods included from Agent::MetadataDSL
#agent_description, #agent_methods, included, #property_descriptions, #property_enum_descriptions
Methods included from Core::Actions
#_deleted?, #change_requests, #changes_applied!, #changes_payload, #create, #destroy, #destroy_request, #op_add!, #op_add_relation!, #op_add_unique!, #op_destroy!, #op_increment!, #op_remove!, #op_remove_relation!, #operate_field!, #prepare_save!, #relation_change_operations, #save, #save!, #set_attributes!, #update, #update!, #update_relations, #uri_path
Methods included from Core::Fetching
#autofetch!, #fetch, #fetch!, #fetch_cache!, #fetch_json, #fetch_object, #prepare_for_dirty_tracking!
Methods included from Associations::HasMany
has_many, #relation_changes?, #relation_updates, #relations
Methods included from Associations::BelongsTo
Methods included from Associations::HasOne
Methods included from Core::ParseReference
format, generate_object_id, parse
Methods included from Core::FieldGuards
Methods included from Core::EnhancedChangeTracking
Methods included from Properties
#apply_attributes!, #attribute_changes?, #attribute_updates, #attributes, #attributes=, #field_map, #fields, #format_operation, #format_value
Methods inherited from Pointer
#==, #[], #[]=, #__type, #attributes, #className, #fetch, #fetch_cache!, #fetch_json, #fetch_object, #fetched?, #hash, #initialize, #json_hash, #method_missing, #pointer, #pointer?, #present?, #respond_to_missing?, #sig
Methods inherited from Model
Methods included from Client::Connectable
Constructor Details
This class inherits a constructor from Parse::Object
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Parse::Pointer
Instance Attribute Details
#download ⇒ String
Returns the file payload for this product download.
44 |
# File 'lib/parse/model/classes/product.rb', line 44 property :download, :file |
#download_name ⇒ String
Returns the name of this download.
48 |
# File 'lib/parse/model/classes/product.rb', line 48 property :download_name |
#icon ⇒ String
An icon file representing this download. This field is required by Parse.
53 |
# File 'lib/parse/model/classes/product.rb', line 53 property :icon, :file, required: true |
#order ⇒ String
The product order number. This field is required by Parse.
58 |
# File 'lib/parse/model/classes/product.rb', line 58 property :order, :integer, required: true |
#product_identifier ⇒ String
The product identifier. This field is required by Parse.
63 |
# File 'lib/parse/model/classes/product.rb', line 63 property :product_identifier, required: true |
#subtitle ⇒ String
The subtitle description for this product. This field is required by Parse.
68 |
# File 'lib/parse/model/classes/product.rb', line 68 property :subtitle, required: true |
#title ⇒ String
The title for this product. This field is required by Parse.
73 |
# File 'lib/parse/model/classes/product.rb', line 73 property :title, required: true |