Class: Parse::SortableGroupBy

Inherits:
GroupBy
  • Object
show all
Defined in:
lib/parse/query.rb

Overview

Sortable version of GroupBy that returns GroupedResult objects instead of plain hashes. Provides the same aggregation methods but with sorting capabilities.

Instance Method Summary collapse

Methods inherited from GroupBy

#initialize, #order, #pipeline, #raw, #sort

Constructor Details

This class inherits a constructor from Parse::GroupBy

Instance Method Details

#average(field) ⇒ GroupedResult Also known as: avg

Calculate average of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to average within each group.

Returns:



7131
7132
7133
7134
# File 'lib/parse/query.rb', line 7131

def average(field)
  results = super
  GroupedResult.new(results, "average")
end

#countGroupedResult

Count the number of items in each group.

Returns:



7115
7116
7117
7118
# File 'lib/parse/query.rb', line 7115

def count
  results = super
  GroupedResult.new(results, "count")
end

#listGroupedResult

Collect Parse::Object instances per group.

Returns:



7156
7157
7158
7159
# File 'lib/parse/query.rb', line 7156

def list
  results = super
  GroupedResult.new(results, "list")
end

#max(field) ⇒ GroupedResult

Find maximum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find maximum for within each group.

Returns:



7149
7150
7151
7152
# File 'lib/parse/query.rb', line 7149

def max(field)
  results = super
  GroupedResult.new(results, "max")
end

#min(field) ⇒ GroupedResult

Find minimum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find minimum for within each group.

Returns:



7141
7142
7143
7144
# File 'lib/parse/query.rb', line 7141

def min(field)
  results = super
  GroupedResult.new(results, "min")
end

#sum(field) ⇒ GroupedResult

Sum a field for each group.

Parameters:

  • field (Symbol, String)

    the field to sum within each group.

Returns:



7123
7124
7125
7126
# File 'lib/parse/query.rb', line 7123

def sum(field)
  results = super
  GroupedResult.new(results, "sum")
end