Class: Parse::SortableGroupBy

Inherits:
GroupBy
  • Object
show all
Defined in:
lib/parse/query.rb

Overview

Sortable version of GroupBy that returns GroupedResult objects instead of plain hashes. Provides the same aggregation methods but with sorting capabilities.

Instance Method Summary collapse

Methods inherited from GroupBy

#initialize, #order, #pipeline, #raw, #sort

Constructor Details

This class inherits a constructor from Parse::GroupBy

Instance Method Details

#average(field) ⇒ GroupedResult Also known as: avg

Calculate average of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to average within each group.

Returns:



6965
6966
6967
6968
# File 'lib/parse/query.rb', line 6965

def average(field)
  results = super
  GroupedResult.new(results, "average")
end

#countGroupedResult

Count the number of items in each group.

Returns:



6949
6950
6951
6952
# File 'lib/parse/query.rb', line 6949

def count
  results = super
  GroupedResult.new(results, "count")
end

#listGroupedResult

Collect Parse::Object instances per group.

Returns:



6990
6991
6992
6993
# File 'lib/parse/query.rb', line 6990

def list
  results = super
  GroupedResult.new(results, "list")
end

#max(field) ⇒ GroupedResult

Find maximum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find maximum for within each group.

Returns:



6983
6984
6985
6986
# File 'lib/parse/query.rb', line 6983

def max(field)
  results = super
  GroupedResult.new(results, "max")
end

#min(field) ⇒ GroupedResult

Find minimum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find minimum for within each group.

Returns:



6975
6976
6977
6978
# File 'lib/parse/query.rb', line 6975

def min(field)
  results = super
  GroupedResult.new(results, "min")
end

#sum(field) ⇒ GroupedResult

Sum a field for each group.

Parameters:

  • field (Symbol, String)

    the field to sum within each group.

Returns:



6957
6958
6959
6960
# File 'lib/parse/query.rb', line 6957

def sum(field)
  results = super
  GroupedResult.new(results, "sum")
end