Class: Parse::SortableGroupBy

Inherits:
GroupBy
  • Object
show all
Defined in:
lib/parse/query.rb

Overview

Sortable version of GroupBy that returns GroupedResult objects instead of plain hashes. Provides the same aggregation methods but with sorting capabilities.

Instance Method Summary collapse

Methods inherited from GroupBy

#initialize, #order, #pipeline, #raw, #sort

Constructor Details

This class inherits a constructor from Parse::GroupBy

Instance Method Details

#average(field) ⇒ GroupedResult Also known as: avg

Calculate average of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to average within each group.

Returns:



6470
6471
6472
6473
# File 'lib/parse/query.rb', line 6470

def average(field)
  results = super
  GroupedResult.new(results)
end

#countGroupedResult

Count the number of items in each group.

Returns:



6454
6455
6456
6457
# File 'lib/parse/query.rb', line 6454

def count
  results = super
  GroupedResult.new(results)
end

#listGroupedResult

Collect Parse::Object instances per group.

Returns:



6495
6496
6497
6498
# File 'lib/parse/query.rb', line 6495

def list
  results = super
  GroupedResult.new(results)
end

#max(field) ⇒ GroupedResult

Find maximum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find maximum for within each group.

Returns:



6488
6489
6490
6491
# File 'lib/parse/query.rb', line 6488

def max(field)
  results = super
  GroupedResult.new(results)
end

#min(field) ⇒ GroupedResult

Find minimum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find minimum for within each group.

Returns:



6480
6481
6482
6483
# File 'lib/parse/query.rb', line 6480

def min(field)
  results = super
  GroupedResult.new(results)
end

#sum(field) ⇒ GroupedResult

Sum a field for each group.

Parameters:

  • field (Symbol, String)

    the field to sum within each group.

Returns:



6462
6463
6464
6465
# File 'lib/parse/query.rb', line 6462

def sum(field)
  results = super
  GroupedResult.new(results)
end