Class: Parse::SortableGroupBy

Inherits:
GroupBy
  • Object
show all
Defined in:
lib/parse/query.rb

Overview

Sortable version of GroupBy that returns GroupedResult objects instead of plain hashes. Provides the same aggregation methods but with sorting capabilities.

Instance Method Summary collapse

Methods inherited from GroupBy

#initialize, #order, #pipeline, #raw, #sort

Constructor Details

This class inherits a constructor from Parse::GroupBy

Instance Method Details

#average(field) ⇒ GroupedResult Also known as: avg

Calculate average of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to average within each group.

Returns:



6367
6368
6369
6370
# File 'lib/parse/query.rb', line 6367

def average(field)
  results = super
  GroupedResult.new(results)
end

#countGroupedResult

Count the number of items in each group.

Returns:



6351
6352
6353
6354
# File 'lib/parse/query.rb', line 6351

def count
  results = super
  GroupedResult.new(results)
end

#listGroupedResult

Collect Parse::Object instances per group.

Returns:



6392
6393
6394
6395
# File 'lib/parse/query.rb', line 6392

def list
  results = super
  GroupedResult.new(results)
end

#max(field) ⇒ GroupedResult

Find maximum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find maximum for within each group.

Returns:



6385
6386
6387
6388
# File 'lib/parse/query.rb', line 6385

def max(field)
  results = super
  GroupedResult.new(results)
end

#min(field) ⇒ GroupedResult

Find minimum value of a field for each group.

Parameters:

  • field (Symbol, String)

    the field to find minimum for within each group.

Returns:



6377
6378
6379
6380
# File 'lib/parse/query.rb', line 6377

def min(field)
  results = super
  GroupedResult.new(results)
end

#sum(field) ⇒ GroupedResult

Sum a field for each group.

Parameters:

  • field (Symbol, String)

    the field to sum within each group.

Returns:



6359
6360
6361
6362
# File 'lib/parse/query.rb', line 6359

def sum(field)
  results = super
  GroupedResult.new(results)
end