Class: Parse::SortableGroupByDate

Inherits:
GroupByDate show all
Defined in:
lib/parse/query.rb

Overview

Sortable version of GroupByDate that returns GroupedResult objects instead of plain hashes. Provides the same aggregation methods but with sorting capabilities.

Instance Method Summary collapse

Methods inherited from GroupByDate

#initialize, #order, #pipeline, #sort

Constructor Details

This class inherits a constructor from Parse::GroupByDate

Instance Method Details

#average(field) ⇒ GroupedResult Also known as: avg

Calculate average of a field for each time period.

Parameters:

  • field (Symbol, String)

    the field to average within each time period.

Returns:



7603
7604
7605
7606
# File 'lib/parse/query.rb', line 7603

def average(field)
  results = super
  GroupedResult.new(results, "average")
end

#countGroupedResult

Count the number of items in each time period.

Returns:



7587
7588
7589
7590
# File 'lib/parse/query.rb', line 7587

def count
  results = super
  GroupedResult.new(results, "count")
end

#max(field) ⇒ GroupedResult

Find maximum value of a field for each time period.

Parameters:

  • field (Symbol, String)

    the field to find maximum for within each time period.

Returns:



7621
7622
7623
7624
# File 'lib/parse/query.rb', line 7621

def max(field)
  results = super
  GroupedResult.new(results, "max")
end

#min(field) ⇒ GroupedResult

Find minimum value of a field for each time period.

Parameters:

  • field (Symbol, String)

    the field to find minimum for within each time period.

Returns:



7613
7614
7615
7616
# File 'lib/parse/query.rb', line 7613

def min(field)
  results = super
  GroupedResult.new(results, "min")
end

#sum(field) ⇒ GroupedResult

Sum a field for each time period.

Parameters:

  • field (Symbol, String)

    the field to sum within each time period.

Returns:



7595
7596
7597
7598
# File 'lib/parse/query.rb', line 7595

def sum(field)
  results = super
  GroupedResult.new(results, "sum")
end